_ORD_A = ord('a')

class Bitmask26:
    def __init__(self, word: str):
        ords = set(ord(c) - _ORD_A for c in word.lower())
        self.mask = sum(1 << i for i in ords if 0 <= i < 26)

    def __eq__(self, other: 'Bitmask26'):
        return self.mask == other.mask
    
    def __hash__(self):
        return self.mask

    def __ge__(self, other: 'Bitmask26'):
        return self.mask | other.mask == self.mask

    def __repr__(self) -> str:
        s = ''.join(chr(i + _ORD_A) for i in range(26) if ((1 << i) & self.mask) != 0)
        return f'bm26[{s}]'



class Bitmask26:
    def __init__(self, arg0: str) -> None: ...
    def __eq__(self, arg0: Bitmask26) -> bool: ...
    def __hash__(self) -> int: ...
    def __repr__(self) -> str: ...
    def __ge__(self, arg0: Bitmask26) -> bool: ...



from pybind11.setup_helpers import Pybind11Extension, build_ext
from setuptools import setup


setup(
    name="bitmask26",
    version="0.2.0",
    author="Adwaith H Sivam",
    author_email="adwaithhs@gmail.com",
    description="A C++ optimized bitmask implementation with Python bindings",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    url="https://github.com/adwaithhs/bitmask26",
    ext_modules=[
        Pybind11Extension(
            "bitmask26",
            ["bitmask26.cpp"],
        ),
    ],
    py_modules=["py_bitmask26"],
    package_data={"": ["bitmask26.pyi"]},
    include_package_data=True,
    cmdclass={"build_ext": build_ext},
    zip_safe=False,
    python_requires=">=3.8",
)
